@@ -303,6 +303,16 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         return mailProperties.isAllowNestedDefaultFolderOnAltNamespace();
     }
 
+    @Override
+    public boolean isEnforceSecureConnection() {
+        return mailProperties.isEnforceSecureConnection();
+    }
+
+    @Override
+    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
+        mailProperties.setEnforceSecureConnection(enforceSecureConnection);
+    }
+
     @Override
     public boolean isIgnoreSubscription() {
         return mailProperties.isIgnoreSubscription();
